# py-aiger-gridworld

Library for modeling gridworlds as AIGER circuits.

[![Build Status](https://cloud.drone.io/api/badges/mvcisback/py-aiger-gridworld/status.svg)](https://cloud.drone.io/mvcisback/py-aiger-gridworld)
[![PyPI version](https://badge.fury.io/py/py-aiger-gridworld.svg)](https://badge.fury.io/py/py-aiger-gridworld)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

<object data="assets/visualization_example.svg" type="image/svg+xml">
  <img src="assets/visualization_example.svg" />
</object>

# Installation

If you just need to use `aiger_gridworld`, you can just run:

`$ pip install py-aiger-gridwolrd`

For developers, note that this project uses the
[poetry](https://poetry.eustace.io/) python package/dependency
management tool. Please familarize yourself with it and then
run:

`$ poetry install`
